@@ -262,6 +262,17 @@ def userinfo(request, *args, **kwargs):
 
 
 class ProviderInfoView(View):
+    def dispatch(self, request, *args, **kwargs):
+        '''overriden dispatch method to append some custom headers'''
+        response = super().dispatch(request, *args, **kwargs)
+
+        if request.method in ['GET', 'HEAD', 'OPTIONS']:
+            response['Access-Control-Allow-Origin'] = '*'
+            response["Access-Control-Allow-Headers"] = \
+                settings.get('OIDC_ACCESS_CONTROL_ALLOW_HEADERS')
+
+        return response
+
     def get(self, request, *args, **kwargs):
         dic = dict()
 
@@ -294,14 +305,20 @@ class ProviderInfoView(View):
             dic['registration_endpoint'] = site_url + reverse('oidc_provider:register')
 
         response = JsonResponse(dic)
-        response['Access-Control-Allow-Origin'] = '*'
-        response["Access-Control-Allow-Headers"] = \
-            settings.get('OIDC_ACCESS_CONTROL_ALLOW_HEADERS')
 
         return response
 
 
 class JwksView(View):
+    def dispatch(self, request, *args, **kwargs):
+        '''overriden dispatch method to append some custom headers'''
+        response = super().dispatch(request, *args, **kwargs)
+        if request.method in ['GET', 'HEAD', 'OPTIONS']:
+            response['Access-Control-Allow-Origin'] = '*'
+            response["Access-Control-Allow-Headers"] = \
+                settings.get('OIDC_ACCESS_CONTROL_ALLOW_HEADERS')
+        return response
+
     def get(self, request, *args, **kwargs):
         dic = dict(keys=[])
 
@@ -317,7 +334,6 @@ class JwksView(View):
             })
 
         response = JsonResponse(dic)
-        response['Access-Control-Allow-Origin'] = '*'
 
         return response
 
